aboutsummaryrefslogtreecommitdiff
path: root/test/functional/core
diff options
context:
space:
mode:
authorJustin M. Keyes <justinkz@gmail.com>2016-09-12 03:43:07 +0200
committerJustin M. Keyes <justinkz@gmail.com>2016-09-12 03:43:07 +0200
commit2daf54ee8dd92accdbc53aa7fb430134072e73e9 (patch)
treee1684d7e82bc02d9a985a7ab58b34c995e02922b /test/functional/core
parentb801291becd19cd462d683dd3f14b71572c02621 (diff)
parentac819b8994079d78fdafb883e6e6144dd9aa952f (diff)
downloadrneovim-2daf54ee8dd92accdbc53aa7fb430134072e73e9.tar.gz
rneovim-2daf54ee8dd92accdbc53aa7fb430134072e73e9.tar.bz2
rneovim-2daf54ee8dd92accdbc53aa7fb430134072e73e9.zip
Merge #4874 'Restore vim-like tab dragging'
Diffstat (limited to 'test/functional/core')
-rw-r--r--test/functional/core/job_spec.lua4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/functional/core/job_spec.lua b/test/functional/core/job_spec.lua
index f764898f72..adbe17d4b5 100644
--- a/test/functional/core/job_spec.lua
+++ b/test/functional/core/job_spec.lua
@@ -109,8 +109,8 @@ describe('jobs', function()
it("will not buffer data if it doesn't end in newlines", function()
if os.getenv("TRAVIS") and os.getenv("CC") == "gcc-4.9"
and helpers.os_name() == "osx" then
- -- XXX: Hangs Travis OSX since e9061117a5b8f195c3f26a5cb94e18ddd7752d86.
- pending("[Hangs on Travis OSX. #5002]", function() end)
+ -- XXX: Hangs Travis macOS since e9061117a5b8f195c3f26a5cb94e18ddd7752d86.
+ pending("[Hangs on Travis macOS. #5002]", function() end)
return
end